
.. image:: https://readthedocs.org/projects/cookiecutter-pywf-open-source-demo/badge/?version=latest
    :target: https://cookiecutter-pywf-open-source-demo.readthedocs.io/en/latest/
    :alt: Documentation Status

.. image:: https://github.com/MacHu-GWU/cookiecutter_pywf_open_source_demo-project/actions/workflows/main.yml/badge.svg
    :target: https://github.com/MacHu-GWU/cookiecutter_pywf_open_source_demo-project/actions?query=workflow:CI

.. image:: https://codecov.io/gh/MacHu-GWU/cookiecutter_pywf_open_source_demo-project/branch/main/graph/badge.svg
    :target: https://codecov.io/gh/MacHu-GWU/cookiecutter_pywf_open_source_demo-project

.. image:: https://img.shields.io/pypi/v/cookiecutter-pywf-open-source-demo.svg
    :target: https://pypi.python.org/pypi/cookiecutter-pywf-open-source-demo

.. image:: https://img.shields.io/pypi/l/cookiecutter-pywf-open-source-demo.svg
    :target: https://pypi.python.org/pypi/cookiecutter-pywf-open-source-demo

.. image:: https://img.shields.io/pypi/pyversions/cookiecutter-pywf-open-source-demo.svg
    :target: https://pypi.python.org/pypi/cookiecutter-pywf-open-source-demo

.. image:: https://img.shields.io/badge/✍️_Release_History!--None.svg?style=social&logo=github
    :target: https://github.com/MacHu-GWU/cookiecutter_pywf_open_source_demo-project/blob/main/release-history.rst

.. image:: https://img.shields.io/badge/⭐_Star_me_on_GitHub!--None.svg?style=social&logo=github
    :target: https://github.com/MacHu-GWU/cookiecutter_pywf_open_source_demo-project

------

.. image:: https://img.shields.io/badge/Link-API-blue.svg
    :target: https://cookiecutter-pywf-open-source-demo.readthedocs.io/en/latest/py-modindex.html

.. image:: https://img.shields.io/badge/Link-Install-blue.svg
    :target: `install`_

.. image:: https://img.shields.io/badge/Link-GitHub-blue.svg
    :target: https://github.com/MacHu-GWU/cookiecutter_pywf_open_source_demo-project

.. image:: https://img.shields.io/badge/Link-Submit_Issue-blue.svg
    :target: https://github.com/MacHu-GWU/cookiecutter_pywf_open_source_demo-project/issues

.. image:: https://img.shields.io/badge/Link-Request_Feature-blue.svg
    :target: https://github.com/MacHu-GWU/cookiecutter_pywf_open_source_demo-project/issues

.. image:: https://img.shields.io/badge/Link-Download-blue.svg
    :target: https://pypi.org/pypi/cookiecutter-pywf-open-source-demo#files


Welcome to ``cookiecutter_pywf_open_source_demo`` Documentation
==============================================================================
.. image:: https://cookiecutter-pywf-open-source-demo.readthedocs.io/en/latest/_static/cookiecutter_pywf_open_source_demo-logo.png
    :target: https://cookiecutter-pywf-open-source-demo.readthedocs.io/en/latest/

Documentation for ``cookiecutter_pywf_open_source_demo``.


.. _install:

Install
------------------------------------------------------------------------------

``cookiecutter_pywf_open_source_demo`` is released on PyPI, so all you need is to:

.. code-block:: console

    $ pip install cookiecutter-pywf-open-source-demo

To upgrade to latest version:

.. code-block:: console

    $ pip install --upgrade cookiecutter-pywf-open-source-demo
